RapidImage
=====
RapidImage is an open source image loading and media management framework for React Native that combines resource pooling, memory and disk caching, and media decoding into a user-friendly interface. 

## Usage

**Note: You must be using React Native 0.60.0 or higher to use the most recent version of `react-native-rapid-image`.**

```bash
yarn add react-native-rapid-image
cd ios && pod install
```

```jsx
import RapidImage from 'react-native-rapid-image'

const YourImage = () => (
    <RapidImage
        style={{ width: 200, height: 200 }}
        source={{
            uri: 'https://unsplash.it/400/400?image=1',
            headers: { Authorization: 'someAuthToken' },
            priority: RapidImage.priority.normal,
        }}
        resizeMode={RapidImage.resizeMode.contain}
    />
)
```
## Are you using Proguard?

If you use Proguard you will need to add these lines to `android/app/proguard-rules.pro`:

```
-keep public class com.agastya.rapidimage.* {*;}
-keep public class com.agastya.rapidimage.** {*;}
-keep public class * implements com.bumptech.glide.module.GlideModule
-keep public class * extends com.bumptech.glide.module.AppGlideModule
-keep public enum com.bumptech.glide.load.ImageHeaderParser$** {
  **[] $VALUES;
  public *;
}
```

## Properties

### `source?: object`

Source for the remote image to load.

---

### `source.uri?: string`

Remote url to load the image from. e.g. `'https://facebook.github.io/react/img/logo_og.png'`.

---

### `source.headers?: object`

Headers to load the image with. e.g. `{ Authorization: 'someAuthToken' }`.

---

### `source.priority?: enum`

-   `RapidImage.priority.low` - Low Priority.
-   `RapidImage.priority.normal` **(Default)** - Normal Priority.
-   `RapidImage.priority.high` - High Priority.

---

### `source.cache?: enum`

-   `RapidImage.cacheControl.immutable` - **(Default)** - Only updates if url changes.
-   `RapidImage.cacheControl.web` - Use headers and follow normal caching procedures.
-   `RapidImage.cacheControl.cacheOnly` - Only show images from cache, do not make any network requests.

---

### `resizeMode?: enum`

-   `RapidImage.resizeMode.contain` - Scale the image uniformly (maintain the image's aspect ratio) so that both dimensions (width and height) of the image will be equal to or less than the corresponding dimension of the view (minus padding).
-   `RapidImage.resizeMode.cover` **(Default)** - Scale the image uniformly (maintain the image's aspect ratio) so that both dimensions (width and height) of the image will be equal to or larger than the corresponding dimension of the view (minus padding).
-   `RapidImage.resizeMode.stretch` - Scale width and height independently, This may change the aspect ratio of the src.
-   `RapidImage.resizeMode.center` - Do not scale the image, keep centered.

---

### `onLoadStart?: () => void`

Called when the image starts to load.

---

### `onProgress?: (event) => void`

Called when the image is loading.

e.g. `onProgress={e => console.log(e.nativeEvent.loaded / e.nativeEvent.total)}`

---

### `onLoad?: (event) => void`

Called on a successful image fetch. Called with the width and height of the loaded image.

e.g. `onLoad={e => console.log(e.nativeEvent.width, e.nativeEvent.height)}`

---

### `onError?: () => void`

Called on an image fetching error.

---

### `onLoadEnd?: () => void`

Called when the image finishes loading, whether it was successful or an error.

---

### `style`

A React Native style. Supports using `borderRadius`.

---

### `fallback: boolean`

If true will fallback to using `Image`.
In this case the image will still be styled and laid out the same way as `RapidImage`.

---

### `tintColor?: number | string`

If supplied, changes the color of all the non-transparent pixels to the given color.

## Static Methods

### `RapidImage.preload: (source[]) => void`

Preload images to display later. e.g.

```js
RapidImage.preload([
    {
        uri: 'https://facebook.github.io/react/img/logo_og.png',
        headers: { Authorization: 'someAuthToken' },
    },
    {
        uri: 'https://facebook.github.io/react/img/logo_og.png',
        headers: { Authorization: 'someAuthToken' },
    },
])
```

### `RapidImage.clearMemoryCache: () => Promise<void>`

Clear all images from memory cache.

### `RapidImage.clearDiskCache: () => Promise<void>`

Clear all images from disk cache.

## Troubleshooting

If you have any problems using this library try the steps in [troubleshooting](docs/troubleshooting.md) and see if they fix it.

## Development

[Follow these instructions to get the example app running.](docs/development.md)

## Supported React Native Versions

This project only aims to support the latest version of React Native.\
This simplifies the development and the testing of the project.

If you require new features or bug fixes for older versions you can fork this project.

## Credits

RapidImage is an iteration from the awesome [react-native-fast-image](https://github.com/DylanVann/react-native-fast-image)
package by [DylanVann](https://github.com/DylanVann). It uses Glide and SDWebImage under the hood.

## Licenses
-   SDWebImage - `MIT`
-   Glide - BSD, part MIT and Apache 2.0. See the [LICENSE](https://github.com/bumptech/glide/blob/master/license) file for details.

