'use strict';

var _extends = require('@babel/runtime/helpers/extends');
var React = require('react');
var reactNative = require('react-native');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const RapidImageViewNativeModule = reactNative.NativeModules.RapidImageView;
const resizeMode = {
  contain: 'contain',
  cover: 'cover',
  stretch: 'stretch',
  center: 'center'
};
const priority = {
  low: 'low',
  normal: 'normal',
  high: 'high'
};
const cacheControl = {
  // Ignore headers, use uri as cache key, fetch only if not in cache.
  immutable: 'immutable',
  // Respect http headers, no aggressive caching.
  web: 'web',
  // Only load from cache.
  cacheOnly: 'cacheOnly'
};

function RapidImageBase({
  source,
  tintColor,
  onLoadStart,
  onProgress,
  onLoad,
  onError,
  onLoadEnd,
  style,
  fallback,
  children,
  // eslint-disable-next-line no-shadow
  resizeMode = 'cover',
  forwardedRef,
  ...props
}) {
  if (fallback) {
    const cleanedSource = { ...source
    };
    delete cleanedSource.cache;
    const resolvedSource = reactNative.Image.resolveAssetSource(cleanedSource);
    return /*#__PURE__*/React__default['default'].createElement(reactNative.View, {
      style: [styles.imageContainer, style],
      ref: forwardedRef
    }, /*#__PURE__*/React__default['default'].createElement(reactNative.Image, _extends__default['default']({}, props, {
      style: reactNative.StyleSheet.absoluteFill,
      source: resolvedSource,
      onLoadStart: onLoadStart,
      onProgress: onProgress,
      onLoad: onLoad,
      onError: onError,
      onLoadEnd: onLoadEnd,
      resizeMode: resizeMode
    })), children);
  }

  const resolvedSource = reactNative.Image.resolveAssetSource(source);
  return /*#__PURE__*/React__default['default'].createElement(reactNative.View, {
    style: [styles.imageContainer, style],
    ref: forwardedRef
  }, /*#__PURE__*/React__default['default'].createElement(RapidImageView, _extends__default['default']({}, props, {
    tintColor: tintColor,
    style: reactNative.StyleSheet.absoluteFill,
    source: resolvedSource,
    onRapidImageLoadStart: onLoadStart,
    onRapidImageProgress: onProgress,
    onRapidImageLoad: onLoad,
    onRapidImageError: onError,
    onRapidImageLoadEnd: onLoadEnd,
    resizeMode: resizeMode
  })), children);
}

const RapidImageMemo = /*#__PURE__*/React.memo(RapidImageBase);
const RapidImageComponent = /*#__PURE__*/React.forwardRef((props, ref) => /*#__PURE__*/React__default['default'].createElement(RapidImageMemo, _extends__default['default']({
  forwardedRef: ref
}, props)));
RapidImageComponent.displayName = 'RapidImage';
const RapidImage = RapidImageComponent;
RapidImage.resizeMode = resizeMode;
RapidImage.cacheControl = cacheControl;
RapidImage.priority = priority;

RapidImage.preload = sources => RapidImageViewNativeModule.preload(sources);

RapidImage.clearMemoryCache = () => RapidImageViewNativeModule.clearMemoryCache();

RapidImage.clearDiskCache = () => RapidImageViewNativeModule.clearDiskCache();

const styles = reactNative.StyleSheet.create({
  imageContainer: {
    overflow: 'hidden'
  }
}); // Types of requireNativeComponent are not correct.

const RapidImageView = reactNative.requireNativeComponent('RapidImageView', RapidImage, {
  nativeOnly: {
    onRapidImageLoadStart: true,
    onRapidImageProgress: true,
    onRapidImageLoad: true,
    onRapidImageError: true,
    onRapidImageLoadEnd: true
  }
});

module.exports = RapidImage;
