import _extends from '@babel/runtime/helpers/extends';
import React, { forwardRef, memo } from 'react';
import { NativeModules, StyleSheet, requireNativeComponent, Image, View } from 'react-native';

const RapidImageViewNativeModule = NativeModules.RapidImageView;
const resizeMode = {
  contain: 'contain',
  cover: 'cover',
  stretch: 'stretch',
  center: 'center'
};
const priority = {
  low: 'low',
  normal: 'normal',
  high: 'high'
};
const cacheControl = {
  // Ignore headers, use uri as cache key, fetch only if not in cache.
  immutable: 'immutable',
  // Respect http headers, no aggressive caching.
  web: 'web',
  // Only load from cache.
  cacheOnly: 'cacheOnly'
};

function RapidImageBase({
  source,
  tintColor,
  onLoadStart,
  onProgress,
  onLoad,
  onError,
  onLoadEnd,
  style,
  fallback,
  children,
  // eslint-disable-next-line no-shadow
  resizeMode = 'cover',
  forwardedRef,
  ...props
}) {
  if (fallback) {
    const cleanedSource = { ...source
    };
    delete cleanedSource.cache;
    const resolvedSource = Image.resolveAssetSource(cleanedSource);
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.imageContainer, style],
      ref: forwardedRef
    }, /*#__PURE__*/React.createElement(Image, _extends({}, props, {
      style: StyleSheet.absoluteFill,
      source: resolvedSource,
      onLoadStart: onLoadStart,
      onProgress: onProgress,
      onLoad: onLoad,
      onError: onError,
      onLoadEnd: onLoadEnd,
      resizeMode: resizeMode
    })), children);
  }

  const resolvedSource = Image.resolveAssetSource(source);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.imageContainer, style],
    ref: forwardedRef
  }, /*#__PURE__*/React.createElement(RapidImageView, _extends({}, props, {
    tintColor: tintColor,
    style: StyleSheet.absoluteFill,
    source: resolvedSource,
    onRapidImageLoadStart: onLoadStart,
    onRapidImageProgress: onProgress,
    onRapidImageLoad: onLoad,
    onRapidImageError: onError,
    onRapidImageLoadEnd: onLoadEnd,
    resizeMode: resizeMode
  })), children);
}

const RapidImageMemo = /*#__PURE__*/memo(RapidImageBase);
const RapidImageComponent = /*#__PURE__*/forwardRef((props, ref) => /*#__PURE__*/React.createElement(RapidImageMemo, _extends({
  forwardedRef: ref
}, props)));
RapidImageComponent.displayName = 'RapidImage';
const RapidImage = RapidImageComponent;
RapidImage.resizeMode = resizeMode;
RapidImage.cacheControl = cacheControl;
RapidImage.priority = priority;

RapidImage.preload = sources => RapidImageViewNativeModule.preload(sources);

RapidImage.clearMemoryCache = () => RapidImageViewNativeModule.clearMemoryCache();

RapidImage.clearDiskCache = () => RapidImageViewNativeModule.clearDiskCache();

const styles = StyleSheet.create({
  imageContainer: {
    overflow: 'hidden'
  }
}); // Types of requireNativeComponent are not correct.

const RapidImageView = requireNativeComponent('RapidImageView', RapidImage, {
  nativeOnly: {
    onRapidImageLoadStart: true,
    onRapidImageProgress: true,
    onRapidImageLoad: true,
    onRapidImageError: true,
    onRapidImageLoadEnd: true
  }
});

export default RapidImage;
