#import "RCTConvert+RapidImage.h"
#import "RapidImageSource.h"

@implementation RCTConvert (RapidImage)

RCT_ENUM_CONVERTER(RapidPriority, (@{
                                   @"low": @(RapidPriorityLow),
                                   @"normal": @(RapidPriorityNormal),
                                   @"high": @(RapidPriorityHigh),
                                   }), RapidPriorityNormal, integerValue);

RCT_ENUM_CONVERTER(RapidCacheControl, (@{
                                       @"immutable": @(RapidCacheControlImmutable),
                                       @"web": @(RapidCacheControlWeb),
                                       @"cacheOnly": @(RapidCacheControlCacheOnly),
                                       }), RapidCacheControlImmutable, integerValue);

+ (RapidImageSource *)RapidImageSource:(id)json {
    if (!json) {
        return nil;
    }
    
    NSString *uriString = json[@"uri"];
    NSURL *uri = [self NSURL:uriString];
    
    RapidPriority priority = [self RapidPriority:json[@"priority"]];
    RapidCacheControl cacheControl = [self RapidCacheControl:json[@"cache"]];
    
    NSDictionary *headers = [self NSDictionary:json[@"headers"]];
    if (headers) {
        __block BOOL allHeadersAreStrings = YES;
        [headers enumerateKeysAndObjectsUsingBlock:^(NSString *key, id header, BOOL *stop) {
            if (![header isKindOfClass:[NSString class]]) {
                RCTLogError(@"Values of HTTP headers passed must be  of type string. "
                            "Value of header '%@' is not a string.", key);
                allHeadersAreStrings = NO;
                *stop = YES;
            }
        }];
        if (!allHeadersAreStrings) {
            // Set headers to nil here to avoid crashing later.
            headers = nil;
        }
    }
    
    RapidImageSource *imageSource = [[RapidImageSource alloc] initWithURL:uri priority:priority headers:headers cacheControl:cacheControl];
    
    return imageSource;
}

RCT_ARRAY_CONVERTER(RapidImageSource);

@end
