#import "RapidImageViewManager.h"
#import "RapidImageView.h"

#import <SDWebImage/SDImageCache.h>
#import <SDWebImage/SDWebImagePrefetcher.h>

@implementation RapidImageViewManager

RCT_EXPORT_MODULE(RapidImageView)

- (RapidImageView*)view {
  return [[RapidImageView alloc] init];
}

RCT_EXPORT_VIEW_PROPERTY(source, RapidImageSource)
RCT_EXPORT_VIEW_PROPERTY(resizeMode, RCTResizeMode)
RCT_EXPORT_VIEW_PROPERTY(onRapidImageLoadStart, RCTDirectEventBlock)
RCT_EXPORT_VIEW_PROPERTY(onRapidImageProgress, RCTDirectEventBlock)
RCT_EXPORT_VIEW_PROPERTY(onRapidImageError, RCTDirectEventBlock)
RCT_EXPORT_VIEW_PROPERTY(onRapidImageLoad, RCTDirectEventBlock)
RCT_EXPORT_VIEW_PROPERTY(onRapidImageLoadEnd, RCTDirectEventBlock)
RCT_REMAP_VIEW_PROPERTY(tintColor, imageColor, UIColor)

RCT_EXPORT_METHOD(preload:(nonnull NSArray<RapidImageSource *> *)sources)
{
    NSMutableArray *urls = [NSMutableArray arrayWithCapacity:sources.count];

    [sources enumerateObjectsUsingBlock:^(RapidImageSource * _Nonnull source, NSUInteger idx, BOOL * _Nonnull stop) {
        [source.headers enumerateKeysAndObjectsUsingBlock:^(NSString *key, NSString* header, BOOL *stop) {
            [[SDWebImageDownloader sharedDownloader] setValue:header forHTTPHeaderField:key];
        }];
        [urls setObject:source.url atIndexedSubscript:idx];
    }];

    [[SDWebImagePrefetcher sharedImagePrefetcher] prefetchURLs:urls];
}

RCT_EXPORT_METHOD(clearMemoryCache:(RCTPromiseResolveBlock)resolve reject:(RCTPromiseRejectBlock)reject)
{
    [SDImageCache.sharedImageCache clearMemory];
    resolve(NULL);
}

RCT_EXPORT_METHOD(clearDiskCache:(RCTPromiseResolveBlock)resolve reject:(RCTPromiseRejectBlock)reject)
{
    [SDImageCache.sharedImageCache clearDiskOnCompletion:^(){
        resolve(NULL);
    }];
}

@end
